'use client'
import useInputMessageStore from '@/feature/messenger/store/chat_store/useInputMessageStore';
import { useTranslation } from '@/hooks/useTranslation';
import { Button, Tooltip } from '@nextui-org/react';
import axios from 'axios';
import React, { useState, useRef, useEffect } from 'react';
import { Smile } from 'react-feather';
import useResponsiveBtn from '@/feature/messenger/hooks/useReponsiveBtn';



export default function EmojiButton() {

    const setMessageInput = useInputMessageStore((state) => state.setMessage);
    const messageInput = useInputMessageStore((state) => state.message);
    const [dropdownVisible, setDropdownVisible] = useState(false);
    const dropdownRef = useRef<HTMLDivElement | null>(null);
    const [emojis, setEmojis] = useState([]);
    const { trans } = useTranslation();
    const { responsiveButtonFooter, responsiveIconButtonFooter } = useResponsiveBtn();


    const handleEmojiClick = (emoji: string) => {
        setMessageInput(messageInput + emoji);
    };

    const handleOutsideClick = (event: any) => {
        if (dropdownRef.current && !dropdownRef.current.contains(event.target)) {
            setDropdownVisible(false);
        }
    };

    useEffect(() => {
        axios.get(`${process.env.ASSET_PREFIX}/chat/api/emoji.json`).then((res) => setEmojis(res.data));
        document.addEventListener('mousedown', handleOutsideClick);
        return () => {
            document.removeEventListener('mousedown', handleOutsideClick);
        };
    }, []);

    return (
        <>
            <div className="relative">
                <div className="inline-block">
                <Tooltip
                    placement="top"
                    content={trans('footer_content_chat_emoji_title')}	
                    color="default"
                >
                    <Button color="primary" radius="full" className={responsiveButtonFooter} variant="flat" onClick={() => setDropdownVisible(!dropdownVisible)}>
                        <Smile size={14} className={responsiveIconButtonFooter} />
                    </Button>
                </Tooltip>
                
                    {dropdownVisible && (
                        <div
                            ref={dropdownRef}
                            className="absolute bottom-full left-0 z-10 border border-gray-300 rounded-xl mb-2 p-2 grid grid-cols-8 gap-2 max-h-48 w-80 overflow-y-scroll bg-white bg-opacity-80 backdrop-blur-lg shadow-lg"
                            >
                            {emojis.map((emoji: any, index) => (
                                <button
                                    key={index}
                                    className="text-xl hover:scale-150 transition-transform ease-in-out duration-200"
                                    onClick={() => handleEmojiClick(emoji.emoji)}
                                >
                                    {emoji.emoji}
                                </button>
                            ))}
                        </div>
                    )}
                </div>
            </div>
        </>
    )
}